@@ -88,7 +88,7 @@ fn get_chunk_size(data_len: usize) -> usize {
     if data_len <= MAX_CHUNK_SIZE {
         data_len
     } else {
-        get_chunk_size(data_len / 2)
+        get_chunk_size(data_len / 2 + (data_len % 2 != 0) as usize)
     }
 }
 
@@ -261,15 +261,15 @@ pub fn validate_chunk(
 mod tests {
     use super::*;
     use std::path::PathBuf;
-    use tokio::fs::File;
-    use tokio::io::AsyncReadExt;
+    use tokio::fs;
 
     #[test]
     fn test_get_chunk_size() -> () {
         assert_eq!(get_chunk_size(MIN_CHUNK_SIZE), MIN_CHUNK_SIZE);
         assert_eq!(get_chunk_size(MAX_CHUNK_SIZE), MAX_CHUNK_SIZE);
         assert_eq!(get_chunk_size(MAX_CHUNK_SIZE * 4), MAX_CHUNK_SIZE);
-        assert_eq!(get_chunk_size(MAX_CHUNK_SIZE + 1), (MAX_CHUNK_SIZE + 1) / 2);
+        assert_eq!(get_chunk_size(MAX_CHUNK_SIZE + 1), 131073);
+        assert_eq!(get_chunk_size(1049784), 131223);
     }
 
     #[tokio::test]
@@ -278,11 +278,8 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/1mb.bin").await?;
-
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         assert_eq!(
             leaves[1],
             Node {
@@ -309,11 +306,9 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/1mb.bin").await?;
 
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         let mut nodes_iter = leaves.into_iter();
         let left = nodes_iter.next().unwrap();
         let right = nodes_iter.next().unwrap();
@@ -343,11 +338,8 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/1mb.bin").await?;
-
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         let layer = build_layer(leaves, &crypto)?;
         assert_eq!(
             layer[0].id,
@@ -367,11 +359,8 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/1mb.bin").await?;
-
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         let root = generate_data_root(leaves, &crypto)?;
         assert_eq!(
             root.id,
@@ -389,17 +378,14 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/0.png").await?;
-
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         let root = generate_data_root(leaves, &crypto)?;
         assert_eq!(
             root.id,
             [
-                216, 248, 50, 181, 40, 249, 132, 35, 200, 106, 229, 132, 126, 90, 154, 0, 40, 87,
-                155, 74, 122, 236, 32, 170, 181, 74, 80, 15, 126, 87, 83, 253,
+                80, 80, 69, 118, 15, 123, 97, 51, 235, 63, 130, 216, 210, 76, 201, 220, 236, 7, 49,
+                169, 83, 37, 80, 107, 186, 166, 114, 203, 209, 56, 127, 13,
             ]
         );
         Ok(())
@@ -411,11 +397,8 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/1mb.bin").await?;
-
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         let root = generate_data_root(leaves, &crypto)?;
 
         let proofs = resolve_proofs(root, None)?;
@@ -508,14 +491,13 @@ mod tests {
             "tests/fixtures/arweave-key-7eV1qae4qVNqsNChg3Scdi-DpOLJPCogct4ixoq1WNg.json",
         ))
         .await?;
-        let mut file = File::open("tests/fixtures/1mb.bin").await?;
-
-        let mut contents = vec![];
-        file.read_to_end(&mut contents).await?;
-        let leaves: Vec<Node> = generate_leaves(contents, &crypto)?;
+        let data = fs::read("tests/fixtures/1mb.bin").await?;
+        let leaves: Vec<Node> = generate_leaves(data, &crypto)?;
         let root = generate_data_root(leaves.clone(), &crypto)?;
         let root_id = root.id.clone();
         let proofs = resolve_proofs(root, None)?;
+        println!("proofs_len: {}", proofs.len());
+        assert_eq!(leaves.len(), proofs.len());
 
         for (chunk, proof) in leaves.into_iter().zip(proofs.into_iter()) {
             assert_eq!((), validate_chunk(root_id.clone(), chunk, proof, &crypto)?);
