@@ -5,6 +5,7 @@ use crate::transaction::Base64;
 
 use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
+use serde_json::{json, Value};
 use std::{cmp::Eq, fmt, hash::Hash, path::PathBuf};
 
 const STRFTIME: &str = "%Y-%m-%d %H:%M:%S";
@@ -70,6 +71,20 @@ impl Default for Status {
     }
 }
 
+impl Status {
+    pub fn header_string(&self, output_format: &OutputFormat) -> String {
+        match output_format {
+            OutputFormat::Display => {
+                format!(
+                    " {:<30}  {:<43}  {:<9}  {}\n{:-<97}",
+                    "path", "id", "status", "confirms", ""
+                )
+            }
+            _ => format!("{}", ""),
+        }
+    }
+}
+
 impl QuietDisplay for Status {
     fn write_str(&self, _w: &mut dyn fmt::Write) -> fmt::Result {
         Ok(())
@@ -80,7 +95,7 @@ impl std::fmt::Display for Status {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         writeln!(
             f,
-            " {:<43}  {}  {:<9}  {:>8}",
+            " {:<30}  {:<43}  {:<9}  {:>8}",
             self.file_path
                 .as_ref()
                 .map(|f| f.display().to_string())
@@ -133,28 +148,103 @@ impl VerboseDisplay for Status {
     }
 }
 
-impl OutputHeader<Status> for Status {
-    fn header_string(output_format: &OutputFormat) -> String {
+#[derive(Serialize, Deserialize, Debug, PartialEq, Clone)]
+pub struct BundleStatus {
+    pub id: Base64,
+    pub status: StatusCode,
+    pub file_paths: Value,
+    pub number_of_files: u64,
+    pub data_size: u64,
+    pub created_at: DateTime<Utc>,
+    pub last_modified: DateTime<Utc>,
+    pub reward: u64,
+    #[serde(flatten)]
+    pub raw_status: Option<RawStatus>,
+    #[serde(flatten)]
+    pub sol_sig: Option<SigResponse>,
+}
+
+impl Default for BundleStatus {
+    fn default() -> Self {
+        Self {
+            id: Base64(vec![]),
+            status: StatusCode::default(),
+            file_paths: json!({}),
+            number_of_files: 0,
+            data_size: 0,
+            created_at: Utc::now(),
+            last_modified: Utc::now(),
+            reward: 0,
+            raw_status: None,
+            sol_sig: None,
+        }
+    }
+}
+
+impl BundleStatus {
+    pub fn header_string(&self, output_format: &OutputFormat) -> String {
         match output_format {
             OutputFormat::Display => {
                 format!(
-                    " {:<43}  {:<43}  {:<9}  {}\n{:-<110}",
-                    "path", "id", "status", "confirms", ""
+                    " {:<43}  {:>6}  {:>6}  {:<11}  {}\n{:-<84}",
+                    "bundle txid", "items", "KB", "status", "confirms", ""
                 )
             }
             _ => format!("{}", ""),
         }
     }
-    fn bundle_header_string(output_format: &OutputFormat) -> String {
-        match output_format {
-            OutputFormat::Display => {
-                format!(
-                    " {:<43}  {:<43}  {:<9}  {}\n{:-<110}",
-                    "manifest", "id", "status", "confirms", ""
-                )
-            }
-            _ => format!("{}", ""),
-        }
+}
+
+impl QuietDisplay for BundleStatus {
+    fn write_str(&self, _w: &mut dyn fmt::Write) -> fmt::Result {
+        Ok(())
+    }
+}
+
+impl std::fmt::Display for BundleStatus {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        writeln!(
+            f,
+            " {:<43}  {:>6}  {:>6}  {:<11} {:>9}",
+            self.id,
+            self.number_of_files,
+            self.data_size / 1000,
+            self.status.to_string(),
+            self.raw_status
+                .as_ref()
+                .map(|f| f.number_of_confirmations)
+                .unwrap_or(0)
+                .to_string(),
+        )
+    }
+}
+
+impl VerboseDisplay for BundleStatus {
+    fn write_str(&self, w: &mut dyn fmt::Write) -> fmt::Result {
+        writeln!(w, "{:<15} {}", "id:", self.id)?;
+        writeln!(w, "{:<15} {:?}", "status:", self.status)?;
+        writeln!(
+            w,
+            "{:<15} {}",
+            "created_at:",
+            self.created_at.format(STRFTIME).to_string()
+        )?;
+        writeln!(
+            w,
+            "{:<15} {}",
+            "last_modified:",
+            self.last_modified.format(STRFTIME).to_string()
+        )?;
+        if let Some(raw_status) = &self.raw_status {
+            writeln!(w, "{:<15} {}", "height:", raw_status.block_height)?;
+            writeln!(w, "{:<15} {}", "indep_hash:", raw_status.block_indep_hash)?;
+            writeln!(
+                w,
+                "{:<15} {}",
+                "confirms:", raw_status.number_of_confirmations
+            )?;
+        };
+        writeln!(w, "")
     }
 }
 
@@ -204,9 +294,6 @@ pub trait OutputHeader<T> {
     fn header_string(output_format: &OutputFormat) -> String
     where
         T: Serialize + fmt::Display + QuietDisplay + VerboseDisplay;
-    fn bundle_header_string(output_format: &OutputFormat) -> String
-    where
-        T: Serialize + fmt::Display + QuietDisplay + VerboseDisplay;
 }
 
 /// Implements output for quiet display output format.
